#!/bin/sh

#  UnmountDmgAndCleanup.sh
#  FuzeLauncher
#
#  Created on 10/28/21.
#  Copyright © Fuze. All rights reserved.

# Logging function writes the given message (LINE) to the given file (LOGNAME), prefixed with a time/date stamp
# Usage: log "LINE" "LOGNAME"
# Make sure to enclose parameters in quotes
log()
{
    LINE=$1
    LOGNAME=$2
    printf "%s: %s\n" "$(date -u '+%Y-%m-%d %H:%M:%S')" "$LINE" >> "$LOGNAME" 2>&1
}

MOUNTED_PATH=$1
LOG_PATH=$2

RESULT=1

declare -i COUNT
COUNT=0
declare -i MAX_TRIES
MAX_TRIES=45

log "Trying To Unmount DMG Path $MOUNTED_PATH ..." "$LOG_PATH"
while [ $RESULT -ne 0 ] && [ $COUNT -lt $MAX_TRIES ];
do
    sleep 1
    /usr/bin/hdiutil detach -verbose "$MOUNTED_PATH" >> "$LOG_PATH" 2>&1
    RESULT=$?
    COUNT+=1
    log "-----" "$LOG_PATH"
done

if [ $RESULT -eq 0 ];then
    log "DMG Ejected Successfully" "$LOG_PATH"
else
    log "Error: DMG Could Not Be Ejected After $COUNT Tries" "$LOG_PATH"
fi

# Move the log to the user's Logs directory, since we're going to delete the enclosing folder
LOG_NAME=`basename "$LOG_PATH"`
MOVED_LOG_PATH="$HOME/Library/Logs/$LOG_NAME"
log "Moving log file $LOG_PATH to $MOVED_LOG_PATH" "$LOG_PATH"
mv "$LOG_PATH" "$MOVED_LOG_PATH"

# Go up two levels because we expect the logs to be in the app support folder and then within a 'logs' folder
# So if we want to remove the whole app support folder, we need to go up two directories
OLD_FILES_DIR=`dirname "$LOG_PATH"`
OLD_FILES_DIR=`dirname "$OLD_FILES_DIR"`
log "Deleting path $OLD_FILES_DIR" "$MOVED_LOG_PATH"

# Invoke removal a second later; by that time, this script is done, so it can be removed without issue
sleep 1 && rm -rf "$OLD_FILES_DIR" && echo `date -u '+%Y-%m-%d %H:%M:%S'`": Deletion Complete" >> "$MOVED_LOG_PATH" &

# This should get printed to the file before the completion message above
log "Finish script" "$MOVED_LOG_PATH"
